"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
require("mocha");
var floodgateClient = require("../src/index");
var test_config_1 = require("./test-config");
describe('Test Targets', function () {
    var config = {
        localConfigData: test_config_1.default,
        consoleLog: false,
        refreshInterval: 3600
    };
    context('Equal To', function () {
        it('should return yellow', function (done) {
            var def = "grey";
            var exp = "yellow";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var attributes = {
                Name: "Peter Parker",
                Country: "US"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", attributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
        it('no user attributes should return red', function (done) {
            var def = "grey";
            var exp = "red";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b");
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
        it('no matching user attributes should return red', function (done) {
            var def = "grey";
            var exp = "red";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Age: "20"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Not Equal To', function () {
        it('should return orange', function (done) {
            var def = "grey";
            var exp = "orange";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Name: "Bruce Banner"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Greater Than', function () {
        it('should return blue', function (done) {
            var def = "grey";
            var exp = "blue";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Score1: "45"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Greater Than and Equal To', function () {
        it('should return green', function (done) {
            var def = "grey";
            var exp = "green";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Score2: "135"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Less Than', function () {
        it('should return yellow', function (done) {
            var def = "grey";
            var exp = "yellow";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Score3: "35"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Less Than and Equal To', function () {
        it('should return blue', function (done) {
            var def = "grey";
            var exp = "blue";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Score4: "120"
            };
            var user = floodgateClient.createUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", "spiderman@marvel.com", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Contains with Old User Object', function () {
        it('should return green', function (done) {
            var def = "grey";
            var exp = "green";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Age: "25"
            };
            var user = floodgateClient.createUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", "random@gmail.com", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Contains with New User Object', function () {
        it('should return green', function (done) {
            var def = "grey";
            var exp = "green";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Email: "random@gmail.com"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Not Contain with Old User Object', function () {
        it('should return yellow', function (done) {
            var def = "grey";
            var exp = "yellow";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Age: "30"
            };
            var user = floodgateClient.createUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", "random@yahoo.co.uk", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Not Contain with New User Object', function () {
        it('should return yellow', function (done) {
            var def = "grey";
            var exp = "yellow";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Email: "random@yahoo.co.uk"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
    context('Ends With', function () {
        it('should return yellow', function (done) {
            var def = "grey";
            var exp = "yellow";
            var client = floodgateClient.createAutoUpdateClient("invalid", config);
            var customAttributes = {
                Country: "United Kingdom"
            };
            var user = floodgateClient.createFloodgateUser("d2405fc0-c9cd-49e7-a07e-bf244d6d360b", customAttributes);
            client.on('ready', function () {
                var key = 'colours';
                var colour = client.GetValue(key, def, user);
                chai_1.expect(colour).to.equal(exp);
                done();
            });
        });
    });
});
//# sourceMappingURL=EvaluateTargetTests.js.map